==> vue-components-1.5.13.tgz: package/lib/ui/radios/src/DescriptionRadioList.vue.rd.js <==
import { computedEager as r, useVModel as y } from "@vueuse/core";
import { defineComponent as g, openBlock as s, createElementBlock as o, createElementVNode as t, toDisplayString as a, createVNode as u, unref as i, normalizeClass as p, withCtx as _, Fragment as m, renderList as v, createBlock as b, createCommentVNode as w } from "vue";
import { RAntRadioButtonGroup as R, RAntRadioButton as f } from "../../../form/index.rd.js";
import { descriptionListRadioProps as B } from "./props.rd.js";
const C = { class: "w-full" }, N = { class: "text-base font-bold text-gray-900 dark:text-white dark:text-white" }, V = { class: "text-1rem leading-5 text-muted" }, E = { class: "mt-4" }, L = /* @__PURE__ */ t("legend", { class: "sr-only" }, "Notification method", -1), A = {
  key: 0,
  class: "w-full divide-y divide-gray-200 dark:divide-slate-700"
}, D = ["value"], z = { class: "min-w-0 flex-1 text-sm" }, F = {
  for: "account-checking",
  class: "font-bold text-muted"
}, G = {
  id: "account-checking-description",
  class: "text-muted"
}, I = { class: "ml-3 flex items-center h-5" }, M = { class: "" }, P = { class: "text-1rem block w-max font-bold text-muted" }, S = { class: "text-.9rem" }, U = {
  key: 0,
  id: "small-description",
  class: "text-muted"
}, Q = /* @__PURE__ */ g({
  __name: "DescriptionRadioList",
  props: B(),
  emits: ["update:value"],
  setup(h, { emit: j }) {
    const n = h, x = r(() => n.position == "inline"), c = r(() => n.position == "right"), d = y(n, "value");
    function k(l) {
      d.value = l;
    }
    return (l, q) => (s(), o("div", C, [
      t("label", N, a(l.title), 1),
      t("p", V, a(l.description), 1),
      t("fieldset", E, [
        L,
        u(i(R), {
          value: i(d),
          class: p({ "w-full": i(c) }),
          "onUpdate:value": k
        }, {
          default: _(() => [
            i(c) ? (s(), o("div", A, [
              (s(!0), o(m, null, v(l.items, (e) => (s(), o("div", {
                key: e.value,
                value: e.value,
                class: "relative flex items-start py-4"
              }, [
                t("div", z, [
                  t("label", F, a(e.text), 1),
                  t("p", G, a(e.description), 1)
                ]),
                t("div", I, [
                  u(i(f), {
                    "aria-describedby": "account-checking-description",
                    value: e.value
                  }, null, 8, ["value"])
                ])
              ], 8, D))), 128))
            ])) : (s(), o("div", {
              key: 1,
              class: p(["space-y-4 flex flex-col items-start", { "!flex-row !space-y-0 space-x-6": i(x) }])
            }, [
              (s(!0), o(m, null, v(l.items, (e) => (s(), b(i(f), {
                key: e.value,
                value: e.value
              }, {
                default: _(() => [
                  t("div", M, [
                    t("span", P, a(e.text), 1),
                    t("div", S, [
                      e.description ? (s(), o("p", U, a(e.description), 1)) : w("", !0)
                    ])
                  ])
                ]),
                _: 2
              }, 1032, ["value"]))), 128))
            ], 2))
          ]),
          _: 1
        }, 8, ["value", "class"])
      ])
    ]));
  }
});
export {
  Q as default
};

==> vue-components-1.6.7.tgz: package/lib/ui/radios/src/DescriptionRadioList.vue.rd.js <==
import { defineComponent as y, openBlock as s, createElementBlock as o, createElementVNode as t, toDisplayString as a, createVNode as r, unref as i, normalizeClass as u, withCtx as p, Fragment as _, renderList as m, createBlock as g, createCommentVNode as b } from "vue";
import { computedEager as v, useVModel as w } from "@vueuse/core";
import { RAntRadioButtonGroup as R, RAntRadioButton as f } from "../../../form/index.rd.js";
import { descriptionListRadioProps as B } from "./props.rd.js";
const C = { class: "w-full" }, N = { class: "text-base font-bold text-gray-900 dark:text-white dark:text-white" }, V = { class: "text-1rem leading-5 text-muted" }, E = { class: "mt-4" }, L = /* @__PURE__ */ t("legend", { class: "sr-only" }, "Notification method", -1), A = {
  key: 0,
  class: "w-full divide-y divide-gray-200 dark:divide-slate-700"
}, D = ["value"], z = { class: "min-w-0 flex-1 text-sm" }, F = {
  for: "account-checking",
  class: "font-bold text-muted"
}, G = {
  id: "account-checking-description",
  class: "text-muted"
}, I = { class: "ml-3 flex items-center h-5" }, M = { class: "" }, P = { class: "text-1rem block w-max font-bold text-muted" }, S = { class: "text-.9rem" }, U = {
  key: 0,
  id: "small-description",
  class: "text-muted"
}, Q = /* @__PURE__ */ y({
  __name: "DescriptionRadioList",
  props: B(),
  emits: ["update:value"],
  setup(h, { emit: j }) {
    const n = h, x = v(() => n.position == "inline"), c = v(() => n.position == "right"), d = w(n, "value");
    function k(l) {
      d.value = l;
    }
    return (l, q) => (s(), o("div", C, [
      t("label", N, a(l.title), 1),
      t("p", V, a(l.description), 1),
      t("fieldset", E, [
        L,
        r(i(R), {
          value: i(d),
          class: u({ "w-full": i(c) }),
          "onUpdate:value": k
        }, {
          default: p(() => [
            i(c) ? (s(), o("div", A, [
              (s(!0), o(_, null, m(l.items, (e) => (s(), o("div", {
                key: e.value,
                value: e.value,
                class: "relative flex items-start py-4"
              }, [
                t("div", z, [
                  t("label", F, a(e.text), 1),
                  t("p", G, a(e.description), 1)
                ]),
                t("div", I, [
                  r(i(f), {
                    "aria-describedby": "account-checking-description",
                    value: e.value
                  }, null, 8, ["value"])
                ])
              ], 8, D))), 128))
            ])) : (s(), o("div", {
              key: 1,
              class: u(["space-y-4 flex flex-col items-start", { "!flex-row !space-y-0 space-x-6": i(x) }])
            }, [
              (s(!0), o(_, null, m(l.items, (e) => (s(), g(i(f), {
                key: e.value,
                value: e.value
              }, {
                default: p(() => [
                  t("div", M, [
                    t("span", P, a(e.text), 1),
                    t("div", S, [
                      e.description ? (s(), o("p", U, a(e.description), 1)) : b("", !0)
                    ])
                  ])
                ]),
                _: 2
              }, 1032, ["value"]))), 128))
            ], 2))
          ]),
          _: 1
        }, 8, ["value", "class"])
      ])
    ]));
  }
});
export {
  Q as default
};
